==> haskell-hasql-pool-0.5.2.2-214-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-pool
version:              0.5.2.2
visibility:           public
id:                   hasql-pool-0.5.2.2-JVVTlIingrM8K56mbZcsOU
key:                  hasql-pool-0.5.2.2-JVVTlIingrM8K56mbZcsOU
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  aa39bfda926dabcb97367b90339c4565
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-pool-0.5.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-pool-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-pool
hs-libraries:         HShasql-pool-0.5.2.2-JVVTlIingrM8K56mbZcsOU
depends:
    base-prelude-1.6.1.1-3tVkkfGg30hKb5GU3wo1qD
    hasql-1.5.0.4-3X2mZlxdWL044URuQ7OkF4
    resource-pool-0.2.3.2-GoxnmSc4Q995sKTSDuBd5z time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.5.2.2-227-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-pool
version:              0.5.2.2
visibility:           public
id:                   hasql-pool-0.5.2.2-9qCcrs4WP0II7HGOYECJ2Z
key:                  hasql-pool-0.5.2.2-9qCcrs4WP0II7HGOYECJ2Z
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  cbc815decb9b97ad40eb4a36be55eb91
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-pool-0.5.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-pool-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-pool
hs-libraries:         HShasql-pool-0.5.2.2-9qCcrs4WP0II7HGOYECJ2Z
depends:
    base-prelude-1.6.1.1-3tVkkfGg30hKb5GU3wo1qD
    hasql-1.5.0.4-6GDwBu1ouGLL97aqfLNtDJ
    resource-pool-0.2.3.2-2ghaoAEpV2r22WQ70y4rca time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
